@@ -2,7 +2,6 @@
 
 This file allows to download the ontologies for local use.
 Special ontologies are provided as enums.
-
 """
 import gzip
 import importlib
@@ -202,7 +201,7 @@ class Ontology:
         return self._ontology
 
 
-def create_ontology_enum(ontology_id: str) -> None:
+def create_ontology_enum(ontology_id: str, pattern: str) -> None:
     """Create enum of the ontology."""
 
     logger.info(f"Create enum: `{ontology_id}`")
@@ -248,7 +247,7 @@ def create_ontology_enum(ontology_id: str) -> None:
             terms[term_id] = {
                 "id": term_id,
                 "var_name": var_name,
-                "name": pronto_term.name,
+                "name": pronto_name.replace('"', "'"),
                 "definition": pronto_term.definition,
             }
     terms_sorted = {}
@@ -267,6 +266,7 @@ def create_ontology_enum(ontology_id: str) -> None:
         context = {
             "ontology_id": ontology_id,
             "terms": terms_sorted,
+            "pattern": pattern,
         }
         module_str = template.render(**context)
         # print(module_str)
@@ -275,13 +275,16 @@ def create_ontology_enum(ontology_id: str) -> None:
         with open(path_module, "w") as f_py:
             f_py.write(module_str)
 
+
+def try_ontology_import(ontology_id: str) -> None:
+    """Try import of created module."""
     # try to import
-    importlib.import_module("pymetadata.metadata.sbo")
+    importlib.import_module(f"pymetadata.metadata.{ontology_id.lower()}")
 
 
 if __name__ == "__main__":
     # download latest versions
-    update_ontology_files()
+    # update_ontology_files()
 
     # load OWL files
     # ofile: OntologyFile
@@ -292,10 +295,13 @@ if __name__ == "__main__":
     #     console.print(ontology)
 
     # convert to python module
-    create_ontology_enum("SBO")
-    create_ontology_enum("KISAO")
-    create_ontology_enum("ECO")
-    # create_ontology_enum("BTO")
+    create_ontology_enum("SBO", r"^SBO_\d{7}$")
+    create_ontology_enum("KISAO", r"^KISAO_\d{7}$")
+    create_ontology_enum("ECO", r"^ECO_\d{7}$")
+
+    try_ontology_import("SBO")
+    try_ontology_import("KISAO")
+    try_ontology_import("ECO")
 
     # for ontology_id in ontology_files:
     #     create_ontology_enum(ontology_id)
